@@ -3,7 +3,7 @@
  *
  * An object oriented GL/GLES Abstraction/Utility Layer
  *
- * Copyright (C) 2007,2008,2009 Intel Corporation.
+ * Copyright (C) 2007,2008,2009,2013 Intel Corporation.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -51,6 +51,8 @@
 #include "cogl-gl-header.h"
 #include "cogl-framebuffer-private.h"
 #include "cogl-onscreen-private.h"
+#include "cogl-fence-private.h"
+#include "cogl-poll-private.h"
 
 typedef struct
 {
@@ -165,7 +167,8 @@ struct _CoglContext
   /* Some simple caching, to minimize state changes... */
   CoglPipeline     *current_pipeline;
   unsigned long     current_pipeline_changes_since_flush;
-  CoglBool          current_pipeline_skip_gl_color;
+  CoglBool          current_pipeline_with_color_attrib;
+  CoglBool          current_pipeline_unknown_color_alpha;
   unsigned long     current_pipeline_age;
 
   CoglBool          gl_blend_enable_cache;
@@ -194,7 +197,9 @@ struct _CoglContext
   GHashTable *swap_callback_closures;
   int next_swap_callback_id;
 
-  CoglOnscreenEventList onscreen_events_queue;
+  CoglList onscreen_events_queue;
+  CoglList onscreen_dirty_queue;
+  CoglClosure *onscreen_dispatch_idle;
 
   CoglGLES2Context *current_gles2_context;
   GQueue gles2_context_stack;
@@ -305,6 +310,9 @@ struct _CoglContext
   GHashTable *uniform_name_hash;
   int n_uniform_names;
 
+  CoglPollSource *fences_poll_source;
+  CoglList fences;
+
   /* This defines a list of function pointers that Cogl uses from
      either GL or GLES. All functions are accessed indirectly through
      these pointers rather than linking to them directly */
