@@ -192,92 +192,6 @@ _cogl_texture_determine_internal_format (CoglPixelFormat src_format,
     return dst_format;
 }
 
-CoglBitmap *
-_cogl_texture_prepare_for_upload (CoglBitmap *src_bmp,
-                                  CoglPixelFormat dst_format,
-                                  CoglPixelFormat *dst_format_out,
-                                  GLenum *out_glintformat,
-                                  GLenum *out_glformat,
-                                  GLenum *out_gltype,
-                                  CoglError **error)
-{
-  CoglContext *ctx = _cogl_bitmap_get_context (src_bmp);
-  CoglPixelFormat src_format = cogl_bitmap_get_format (src_bmp);
-  CoglBitmap *dst_bmp;
-
-  dst_format = _cogl_texture_determine_internal_format (src_format,
-                                                        dst_format);
-
-  /* OpenGL supports specifying a different format for the internal
-     format when uploading texture data. We should use this to convert
-     formats because it is likely to be faster and support more types
-     than the Cogl bitmap code. However under GLES the internal format
-     must be the same as the bitmap format and it only supports a
-     limited number of formats so we must convert using the Cogl
-     bitmap code instead */
-
-  /* If the driver doesn't natively support alpha textures then it
-   * won't work correctly to convert to/from component-alpha
-   * textures */
-
-  if ((ctx->private_feature_flags & COGL_PRIVATE_FEATURE_FORMAT_CONVERSION) &&
-      ((ctx->private_feature_flags & COGL_PRIVATE_FEATURE_ALPHA_TEXTURES) ||
-       (src_format != COGL_PIXEL_FORMAT_A_8 &&
-        dst_format != COGL_PIXEL_FORMAT_A_8) ||
-       src_format == dst_format))
-    {
-      /* If the source format does not have the same premult flag as the
-         dst format then we need to copy and convert it */
-      if (_cogl_texture_needs_premult_conversion (src_format,
-                                                  dst_format))
-        {
-          dst_bmp = _cogl_bitmap_convert (src_bmp,
-                                          src_format ^ COGL_PREMULT_BIT,
-                                          error);
-
-          if (dst_bmp == NULL)
-            return NULL;
-        }
-      else
-        dst_bmp = cogl_object_ref (src_bmp);
-
-      /* Use the source format from the src bitmap type and the internal
-         format from the dst format type so that GL can do the
-         conversion */
-      ctx->driver_vtable->pixel_format_to_gl (ctx,
-                                              src_format,
-                                              NULL, /* internal format */
-                                              out_glformat,
-                                              out_gltype);
-      ctx->driver_vtable->pixel_format_to_gl (ctx,
-                                              dst_format,
-                                              out_glintformat,
-                                              NULL,
-                                              NULL);
-
-    }
-  else
-    {
-      CoglPixelFormat closest_format;
-
-      closest_format = ctx->driver_vtable->pixel_format_to_gl (ctx,
-                                                               dst_format,
-                                                               out_glintformat,
-                                                               out_glformat,
-                                                               out_gltype);
-
-      if (closest_format != src_format)
-        dst_bmp = _cogl_bitmap_convert (src_bmp, closest_format, error);
-      else
-        dst_bmp = cogl_object_ref (src_bmp);
-    }
-
-  if (dst_format_out)
-    *dst_format_out = dst_format;
-
-  return dst_bmp;
-}
-
 CoglBool
 _cogl_texture_is_foreign (CoglTexture *texture)
 {
