@@ -115,7 +115,7 @@ paint (Data *data)
   cogl_framebuffer_rotate (fb, rotation, 0, 1, 0);
   cogl_framebuffer_rotate (fb, rotation, 1, 0, 0);
 
-  cogl_framebuffer_draw_primitive (fb, data->crate_pipeline, data->prim);
+  cogl_primitive_draw (data->prim, fb, data->crate_pipeline);
 
   cogl_framebuffer_pop_matrix (fb);
 
@@ -220,10 +220,11 @@ main (int argc, char **argv)
 
   /* Load a jpeg crate texture from a file */
   printf ("crate.jpg (CC by-nc-nd http://bit.ly/9kP45T) ShadowRunner27 http://bit.ly/m1YXLh\n");
-  data.texture = cogl_texture_new_from_file (COGL_EXAMPLES_DATA "crate.jpg",
-                                             COGL_TEXTURE_NO_SLICING,
-                                             COGL_PIXEL_FORMAT_ANY,
-                                             &error);
+  data.texture = COGL_TEXTURE (
+    cogl_texture_2d_new_from_file (ctx,
+                                   COGL_EXAMPLES_DATA "crate.jpg",
+                                   COGL_PIXEL_FORMAT_ANY,
+                                   &error));
   if (!data.texture)
     g_error ("Failed to load texture: %s", error->message);
 
