@@ -46,7 +46,7 @@ paint_cb (void *user_data)
     cogl_pop_gles2_context (data->ctx);
 
     /* Draw scene with Cogl */
-    cogl_framebuffer_draw_primitive (data->fb, data->pipeline, data->triangle);
+    cogl_primitive_draw (data->triangle, data->fb, data->pipeline);
 
     cogl_onscreen_swap_buffers (COGL_ONSCREEN (data->fb));
 
@@ -95,11 +95,11 @@ main (int argc, char **argv)
                                              3, triangle_vertices);
     data.pipeline = cogl_pipeline_new (data.ctx);
 
-    data.offscreen_texture =
-      cogl_texture_new_with_size (OFFSCREEN_WIDTH,
-                                  OFFSCREEN_HEIGHT,
-                                  COGL_TEXTURE_NO_SLICING,
-                                  COGL_PIXEL_FORMAT_ANY);
+    data.offscreen_texture = COGL_TEXTURE (
+      cogl_texture_2d_new_with_size (data.ctx,
+                                     OFFSCREEN_WIDTH,
+                                     OFFSCREEN_HEIGHT,
+                                     COGL_PIXEL_FORMAT_ANY));
     data.offscreen = cogl_offscreen_new_to_texture (data.offscreen_texture);
 
     data.gles2_ctx = cogl_gles2_context_new (data.ctx, &error);
