@@ -266,13 +266,14 @@ make_texture (void)
       *(--p) = 255;
     }
 
-  tex = cogl_texture_new_from_data (TEXTURE_SIZE,
-                                    TEXTURE_SIZE,
-                                    COGL_TEXTURE_NO_ATLAS,
-                                    COGL_PIXEL_FORMAT_RGBA_8888,
-                                    COGL_PIXEL_FORMAT_ANY,
-                                    TEXTURE_SIZE * 4,
-                                    tex_data);
+  tex = test_utils_texture_new_from_data (test_ctx,
+                                          TEXTURE_SIZE,
+                                          TEXTURE_SIZE,
+                                          TEST_UTILS_TEXTURE_NO_ATLAS,
+                                          COGL_PIXEL_FORMAT_RGBA_8888,
+                                          COGL_PIXEL_FORMAT_ANY,
+                                          TEXTURE_SIZE * 4,
+                                          tex_data);
 
   g_free (tex_data);
 
@@ -292,9 +293,11 @@ test_backface_culling (void)
 
   state.texture = make_texture ();
 
-  tex = cogl_texture_new_with_size (state.width, state.height,
-                                    COGL_TEXTURE_NO_SLICING,
-                                    COGL_PIXEL_FORMAT_ANY); /* internal fmt */
+  tex = test_utils_texture_new_with_size (test_ctx,
+                                          state.width, state.height,
+                                          TEST_UTILS_TEXTURE_NO_SLICING,
+                                          COGL_PIXEL_FORMAT_ANY); /* internal
+                                                                     format */
   state.offscreen = COGL_FRAMEBUFFER (cogl_offscreen_new_to_texture (tex));
   state.offscreen_tex = tex;
 
